{ config, lib, ... }:

let
  home-manager = (import ../nix/sources.nix).home-manager;
  unstable = import <nixos-unstable> { };
in
{
  imports = [
    "${home-manager}/nixos"
  ];


  home-manager.users.fleaz = { pkgs, ... }: {
    imports = [
      modules/neovim.nix
      modules/vscode.nix
      modules/direnv.nix
      modules/sway.nix
      modules/waybar.nix
      modules/git.nix
      modules/gpg.nix
      modules/udiskie.nix
      modules/discord.nix
      modules/devenv.nix
      modules/overlay.nix
      modules/zsh.nix
      modules/foot.nix
      modules/manual.nix
      modules/tig.nix
      modules/mako.nix
      modules/nm-applet.nix
      modules/blueman-applet.nix
      ../secrets/ssh-config.nix
    ] ++ lib.optionals (config.networking.hostName == "smithers") [
      modules/kanshi.nix
    ];

    home.packages = with pkgs; [
      httpie
      wdisplays
      firefox
      evince
      chromium
      via
      nextcloud-client
      deluge
      gnupg
      loupe
      hicolor-icon-theme
      nemo
      element-desktop
      signal-desktop
      nix-output-monitor
      samba

      dnsutils
      mtr
      tig
      ncdu
      fd
      silver-searcher
      ripgrep
      thunderbird
      mosh
      mpv
      go
      python3
      pavucontrol
      playerctl
      jq
      psmisc
      zip
      nmap
      vnstat
      whois
      sipcalc
      vnstat
      strace
      usbutils
      pciutils

      swaylock
      swayidle
      brightnessctl
      wl-clipboard
      sway-contrib.grimshot
      albert
      foot
      wofi
      unzip
      whois
      sublime-music
      fzf
      ncmpcpp
      acpi
      unstable.joplin-desktop
      bat

      prusa-slicer
      orca-slicer
      htop
      xdg-utils
      moreutils
      insomnia
      mumble
      inkscape
      guvcview
      vnstat
      gedit
      pwgen
      magic-wormhole
      #kicad
      picocom
      wirelesstools
      xournal
      nix-tree

      # kubernetes stuff
      kubectl
      krew
      kubectx

    ] ++ lib.optionals (config.my.isLaptop) [
      networkmanager
    ];

    home.stateVersion = "21.11";

    gtk = {
      enable = true;
      theme = {
        name = "Adwaita";
        package = pkgs.adwaita-icon-theme;
      };
    };

    xdg = {
      enable = true;
    };

    services.gnome-keyring.enable = true;

    # e.g. for  vscode
    nixpkgs.config.allowUnfree = true;

    programs.git = {
      enable = true;
      userName = "fleaz";
      userEmail = "mail@felixbreidenstein.de";
    };

    services.gammastep = {
      enable = true;
      tray = true;
      latitude = "49.8";
      longitude = "8.6";
      temperature = {
        day = 5500;
        night = 3000;
      };

    };
  };
}
